from milkman_py.main import (
    univ2_expected_out_data,
    univ3_expected_out_data,
    curve_expected_out_data,
    chainlink_expected_out_data,
    meta_expected_out_data,
    fixed_slippage_price_checker_data,
    dynamic_slippage_price_checker_data,
)
